"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var graphql_codegen_core_1 = require("graphql-codegen-core");
var fs = require("fs");
var path = require("path");
var document_finder_1 = require("../../utils/document-finder");
exports.loadFileContent = function (filePath) {
    if (fs.existsSync(filePath)) {
        var fileContent = fs.readFileSync(filePath, 'utf8');
        var fileExt = path.extname(filePath);
        if (fileExt === '.graphql' || fileExt === '.gql') {
            return graphql_codegen_core_1.parse(new graphql_codegen_core_1.Source(fileContent, filePath));
        }
        var foundDoc = document_finder_1.extractDocumentStringFromCodeFile(fileContent);
        if (foundDoc) {
            return graphql_codegen_core_1.parse(new graphql_codegen_core_1.Source(foundDoc, filePath));
        }
        else {
            return null;
        }
    }
    else {
        throw new Error("Document file " + filePath + " does not exists!");
    }
};
exports.loadDocumentsSources = function (schema, filePaths) {
    var loadResults = filePaths
        .map(function (filePath) {
        var fileContent = exports.loadFileContent(filePath);
        var errors = graphql_1.validate(schema, fileContent);
        return {
            fileContent: fileContent,
            errors: errors
        };
    })
        .filter(function (content) { return content; });
    var errors = loadResults.map(function (r) { return r.errors; }).reduce(function (soFar, current) { return soFar.concat(current); }, []);
    return errors.length > 0 ? errors : graphql_codegen_core_1.concatAST(loadResults.map(function (r) { return r.fileContent; }));
};
//# sourceMappingURL=document-loader.js.map